@@ -138,6 +138,9 @@ mc.gbart <- function(
             if(keeptest) post$yhat.test <- rbind(post$yhat.test,
                                                  post.list[[i]]$yhat.test)
 
+            if(type=='wbart')
+                post$sigma <- cbind(post$sigma, post.list[[i]]$sigma)
+
             post$varcount <- rbind(post$varcount, post.list[[i]]$varcount)
             post$varprob <- rbind(post$varprob, post.list[[i]]$varprob)
 
