@@ -10,10 +10,12 @@ extern SEXP clbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, S
 extern SEXP cpwbart(SEXP, SEXP, SEXP);
 extern SEXP cwbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP cgbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+/*extern SEXP cgbmm(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);*/
 extern SEXP cabart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 /*extern SEXP cspbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);*/
 extern SEXP mc_cores_openmp();
 extern SEXP crtnorm(SEXP, SEXP, SEXP);
+extern SEXP crtgamma(SEXP, SEXP, SEXP);
 extern SEXP cdraw_lambda_i(SEXP, SEXP, SEXP, SEXP);
 /*extern SEXP cdpmbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP cdpmwbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);*/
@@ -21,14 +23,16 @@ extern SEXP cdpmwbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP
 static const R_CallMethodDef CallEntries[] = {
     {"cpbart",  (DL_FUNC) &cpbart,  27},
     {"clbart",  (DL_FUNC) &clbart,  24},
-//    {"cmbart",  (DL_FUNC) &cmbart,  29},
+/*    {"cmbart",  (DL_FUNC) &cmbart,  29},*/
     {"cpwbart", (DL_FUNC) &cpwbart,  3},
     {"cwbart",  (DL_FUNC) &cwbart,  31},
     {"cgbart",  (DL_FUNC) &cgbart,  30},
+/*    {"cgbmm",   (DL_FUNC) &cgbmm,   34}, */
     {"cabart",  (DL_FUNC) &cabart,  31},
 /*  {"cspbart",  (DL_FUNC) &cspbart,  30}, */
     {"mc_cores_openmp",(DL_FUNC) &mc_cores_openmp,0},
-    {"crtnorm", (DL_FUNC) &crtnorm, 3},
+    {"crtnorm", (DL_FUNC) &crtnorm,  3},
+    {"crtgamma",(DL_FUNC) &crtgamma, 3},
     {"cdraw_lambda_i", (DL_FUNC) &cdraw_lambda_i, 4},
 /*  {"cdpmbart",(DL_FUNC) &cdpmbart,25},
     {"cdpmwbart",(DL_FUNC) &cdpmwbart,27}, */
